@@ -591,8 +591,8 @@ class Base(Controller):
 
         # shows the path of the config
         if self.app.pargs.action=='loc':
-            from ..ext.config import show_config_path
-            show_config_path()
+            config_path = os.path.join(os.path.expanduser('~'), 'dt_config.json')
+            print(config_path)
 
         # resets the config
         # TODO this config method needs programmatic acces for spot instances
@@ -608,7 +608,11 @@ class Base(Controller):
         help='All Github related operations',
         arguments=[
              (['action'],{
-                "help" : "To show one of {forks, contrib, diff}.",
+                "help" : """To show one of {ff, fs, contrib, diff}. \r\n
+                ff: Finds the forks of a repo.  \r\n
+                fs: Finds the last commit of a repo by fork. \r\n 
+                contrib: Finds the contributors of a repo. \r\n
+                diff: Finds the all the diffs in directories below. """,
                 "action" : "store"
             }),
             (['-url'],{
@@ -618,13 +622,16 @@ class Base(Controller):
         ]
     )
     def gh(self):
-        if self.app.pargs.action=='forks':
+        if self.app.pargs.action=='ff':
             from ..ext.github import find_forks
             print(find_forks(self.app.pargs.url))
-        if self.app.pargs.action=='contrib':
+        elif self.app.pargs.action=='fs':
+            from ..ext.github import fork_status
+            print(fork_status(self.app.pargs.url))
+        elif self.app.pargs.action=='contrib':
             from ..ext.github import find_contributors
             print(find_contributors(self.app.pargs.url))
-        if self.app.pargs.action=='diff':
+        elif self.app.pargs.action=='diff':
             from ..ext.github import dir_diff
             pp(dir_diff(self.app.pargs.url))
 
