@@ -176,7 +176,6 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file
     else:
         df = get_drives_df(s3_resource, bucket_name, dongle_id=target, filter=filter)
 
-    # TODO: fix unkown bug
     df = df[df.drive_time.str.len() > 16 ]
 
     df['upload_time'] = df.drive.str.split('--').str[:-1].str.join('--')
@@ -189,7 +188,7 @@ def get_drives(target, bucket_name: str = 'creationlabs-raw-data', metadata_file
     if target in ['0', '-1']:
         if filter: 
             df = add_metadata(df, metadata_file)
-            target_columns = ['dongle_id','drive','time','seg_num','Registration_Number', 'Logistics_Firm']
+            target_columns = ['dongle_id','drive','time','seg_num','Registration_Number', 'Company']
             print(df[target_columns])
         else: print(df[['dongle_id','drive','time','seg_num']])
     else:
@@ -237,6 +236,10 @@ def add_metadata(df: pd.DataFrame, metadata_file_path: str):
     # remove all rows with na in Dongle_ID
     meta_data = meta_data[~meta_data.Dongle_ID.isna()]
 
+    # remove values where Deprecated = True
+    meta_data = meta_data[~(meta_data.Deprecated==True)]
+    
     # merge the two dataframes
     df = df.merge(meta_data, left_on='dongle_id', right_on="Dongle_ID")
+    
     return df
\ No newline at end of file
